Class: Google::Apis::TpuV1alpha1::TPUService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::TpuV1alpha1::TPUService
- Defined in:
- lib/google/apis/tpu_v1alpha1/service.rb
Overview
Cloud TPU API
TPU API provides customers with access to Google TPU technology.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://tpu.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_node(parent, node_object = nil, node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Creates a node.
-
#delete_project_location_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Deletes a node.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Location
Gets information about a location.
-
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::AcceleratorType
Gets AcceleratorType.
-
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Node
Gets the details of a node.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Gets the latest state of a long-running operation.
-
#get_project_location_tensorflow_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::TensorFlowVersion
Gets TensorFlow Version.
-
#initialize ⇒ TPUService
constructor
A new instance of TPUService.
-
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
-
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListNodesResponse
Lists nodes.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_tensorflow_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListTensorFlowVersionsResponse
Lists TensorFlow versions supported by this API.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#reimage_project_location_node(name, reimage_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Reimages a node's OS.
-
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Starts a node.
-
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Stops a node.
Constructor Details
#initialize ⇒ TPUService
Returns a new instance of TPUService.
47 48 49 50 51 52 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-tpu_v1alpha1', client_version: Google::Apis::TpuV1alpha1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
471 472 473 474 475 476 477 478 479 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 471 def cancel_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:cancel', ) command.response_representation = Google::Apis::TpuV1alpha1::Empty::Representation command.response_class = Google::Apis::TpuV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_node(parent, node_object = nil, node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Creates a node.
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 232 def create_project_location_node(parent, node_object = nil, node_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+parent}/nodes', ) command.request_representation = Google::Apis::TpuV1alpha1::Node::Representation command.request_object = node_object command.response_representation = Google::Apis::TpuV1alpha1::Operation::Representation command.response_class = Google::Apis::TpuV1alpha1::Operation command.params['parent'] = parent unless parent.nil? command.query['nodeId'] = node_id unless node_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Deletes a node.
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 268 def delete_project_location_node(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::Operation::Representation command.response_class = Google::Apis::TpuV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 504 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::Empty::Representation command.response_class = Google::Apis::TpuV1alpha1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::Location::Representation command.response_class = Google::Apis::TpuV1alpha1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::AcceleratorType
Gets AcceleratorType.
155 156 157 158 159 160 161 162 163 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 155 def get_project_location_accelerator_type(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::AcceleratorType::Representation command.response_class = Google::Apis::TpuV1alpha1::AcceleratorType command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_node(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Node
Gets the details of a node.
299 300 301 302 303 304 305 306 307 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 299 def get_project_location_node(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::Node::Representation command.response_class = Google::Apis::TpuV1alpha1::Node command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
535 536 537 538 539 540 541 542 543 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 535 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::Operation::Representation command.response_class = Google::Apis::TpuV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_tensorflow_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::TensorFlowVersion
Gets TensorFlow Version.
614 615 616 617 618 619 620 621 622 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 614 def get_project_location_tensorflow_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}', ) command.response_representation = Google::Apis::TpuV1alpha1::TensorFlowVersion::Representation command.response_class = Google::Apis::TpuV1alpha1::TensorFlowVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListAcceleratorTypesResponse
Lists accelerator types supported by this API.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 193 def list_project_location_accelerator_types(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/acceleratorTypes', ) command.response_representation = Google::Apis::TpuV1alpha1::ListAcceleratorTypesResponse::Representation command.response_class = Google::Apis::TpuV1alpha1::ListAcceleratorTypesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListNodesResponse
Lists nodes.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 333 def list_project_location_nodes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/nodes', ) command.response_representation = Google::Apis::TpuV1alpha1::ListNodesResponse::Representation command.response_class = Google::Apis::TpuV1alpha1::ListNodesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
580 581 582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 580 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/operations', ) command.response_representation = Google::Apis::TpuV1alpha1::ListOperationsResponse::Representation command.response_class = Google::Apis::TpuV1alpha1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_tensorflow_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListTensorFlowVersionsResponse
Lists TensorFlow versions supported by this API.
652 653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 652 def list_project_location_tensorflow_versions(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+parent}/tensorflowVersions', ) command.response_representation = Google::Apis::TpuV1alpha1::ListTensorFlowVersionsResponse::Representation command.response_class = Google::Apis::TpuV1alpha1::ListTensorFlowVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 121 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha1/{+name}/locations', ) command.response_representation = Google::Apis::TpuV1alpha1::ListLocationsResponse::Representation command.response_class = Google::Apis::TpuV1alpha1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reimage_project_location_node(name, reimage_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Reimages a node's OS.
366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 366 def reimage_project_location_node(name, reimage_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:reimage', ) command.request_representation = Google::Apis::TpuV1alpha1::ReimageNodeRequest::Representation command.request_object = reimage_node_request_object command.response_representation = Google::Apis::TpuV1alpha1::Operation::Representation command.response_class = Google::Apis::TpuV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Starts a node.
399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 399 def start_node(name, start_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:start', ) command.request_representation = Google::Apis::TpuV1alpha1::StartNodeRequest::Representation command.request_object = start_node_request_object command.response_representation = Google::Apis::TpuV1alpha1::Operation::Representation command.response_class = Google::Apis::TpuV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::TpuV1alpha1::Operation
Stops a node. This operation is only available with single TPU nodes.
432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/google/apis/tpu_v1alpha1/service.rb', line 432 def stop_node(name, stop_node_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha1/{+name}:stop', ) command.request_representation = Google::Apis::TpuV1alpha1::StopNodeRequest::Representation command.request_object = stop_node_request_object command.response_representation = Google::Apis::TpuV1alpha1::Operation::Representation command.response_class = Google::Apis::TpuV1alpha1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |